/*
 * Copyright (c) 2013, Michael Hanselmann.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the name of the copyright holder nor the names of contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define BOOST_TEST_MODULE Capacity
#include <boost/test/unit_test.hpp>

#include <qrencode.h>

#include "../src/capacity.hpp"

BOOST_AUTO_TEST_CASE(TestChooseQrVersionZeroBytes)
{
  using ::QrBackup::ChooseQrVersion;

  const auto result = ChooseQrVersion(0, QR_ECLEVEL_L);

  BOOST_CHECK_EQUAL(result.first, 1);
  BOOST_CHECK_EQUAL(result.second, 17);
}

BOOST_AUTO_TEST_CASE(TestChooseQrVersionMedium)
{
  using ::QrBackup::ChooseQrVersion;

  const auto result = ChooseQrVersion(1024, QR_ECLEVEL_Q);

  BOOST_CHECK_EQUAL(result.first, 31);
  BOOST_CHECK_EQUAL(result.second, 1030);
}

BOOST_AUTO_TEST_CASE(TestChooseQrVersionLarge)
{
  using ::QrBackup::ChooseQrVersion;

  const auto result = ChooseQrVersion(16 * 1024, QR_ECLEVEL_H);

  BOOST_CHECK_EQUAL(result.first, QRSPEC_VERSION_MAX);
  BOOST_CHECK_EQUAL(result.second, 1273);
}

BOOST_AUTO_TEST_CASE(TestChooseQrVersionAlmostLargest)
{
  using ::QrBackup::ChooseQrVersion;

  const auto result = ChooseQrVersion(2876, QR_ECLEVEL_L);

  BOOST_CHECK_EQUAL(result.first, QRSPEC_VERSION_MAX);
  BOOST_CHECK_EQUAL(result.second, 2953);
}

/* vim: set sw=2 sts=2 et : */
