/*
 * Copyright (c) 2013, Michael Hanselmann.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the name of the copyright holder nor the names of contributors
 *   may be used to endorse or promote products derived from this software
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <system_error>
#include <fstream>

#include <fcntl.h>

#define BOOST_TEST_MODULE Utilities
#include <boost/test/unit_test.hpp>

#include "../src/posixfile.hpp"
#include "utils.hpp"

BOOST_AUTO_TEST_CASE(TestPosixFile)
{
  using ::QrBackup::PosixFile;

  const WithTemporaryDirectory tmpdir;

  boost::filesystem::path tmpfile{tmpdir.get() / "test.txt"};

  {
    std::ofstream fh;
    fh.open(tmpfile.c_str(), std::ios::out | std::ios::binary);
    fh.close();
  }

  const PosixFile pf{tmpfile.native(), O_RDONLY, 0600};
  BOOST_CHECK_GT(pf.get(), 0);
}

BOOST_AUTO_TEST_CASE(TestPosixFileNonExistent)
{
  using ::QrBackup::PosixFile;

  const WithTemporaryDirectory tmpdir;

  boost::filesystem::path tmpfile{tmpdir.get() / "does-not-exist"};

  BOOST_CHECK_THROW(PosixFile(tmpfile.c_str(), O_RDONLY, 0600),
                    std::system_error);
}

/* vim: set sw=2 sts=2 et : */
